@@ -1,21 +1,9 @@
 # Copyright 2008-2015 Free Software Foundation, Inc.
 # This file is part of GNU Radio
 #
-# GNU Radio Companion is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
+# SPDX-License-Identifier: GPL-2.0-or-later
 #
-# GNU Radio Companion is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
-from __future__ import absolute_import, print_function
 
 import collections
 import itertools
@@ -56,6 +44,7 @@ class FlowGraph(Element):
 
         self._eval_cache = {}
         self.namespace = {}
+        self.imported_names = []
 
         self.grc_file_path = ''
 
@@ -117,7 +106,7 @@ class FlowGraph(Element):
 
         output = []
         for snip in snippets:
-            d ={}
+            d = {}
             sect = snip.params['section'].value
             d['section'] = sect
             d['priority'] = snip.params['priority'].value
@@ -127,7 +116,7 @@ class FlowGraph(Element):
             if not section or sect == section:
                 output.append(d)
 
-        # Sort by descending priority 
+        # Sort by descending priority
         if section:
             output = sorted(output, key=lambda x: x['priority'], reverse=True)
 
@@ -202,6 +191,16 @@ class FlowGraph(Element):
         except Exception as e:
             raise ValueError("Can't parse run command {!r}: {}".format(run_command, e))
 
+    def get_imported_names(self):
+        """
+        Get a lis of imported names.
+        These names may not be used as id's
+
+        Returns:
+            a list of imported names
+        """
+        return self.imported_names
+
     ##############################################
     # Access Elements
     ##############################################
@@ -217,7 +216,7 @@ class FlowGraph(Element):
         return elements
 
     def children(self):
-        return itertools.chain(self.iter_enabled_blocks(), self.connections)
+        return itertools.chain(self.blocks, self.connections)
 
     def rewrite(self):
         """
@@ -241,6 +240,8 @@ class FlowGraph(Element):
                 log.exception('Failed to evaluate import expression "{0}"'.format(expr), exc_info=True)
                 pass
 
+        self.imported_names = list(namespace.keys())
+
         for id, expr in self.get_python_modules():
             try:
                 module = types.ModuleType(id)
@@ -268,7 +269,7 @@ class FlowGraph(Element):
                 value = eval(variable_block.value, namespace, variable_block.namespace)
                 namespace[variable_block.name] = value
                 self.namespace.update(namespace) # rewrite on subsequent blocks depends on an updated self.namespace 
-            except TypeError: #Type Errors may happen, but that desn't matter as they are displayed in the gui
+            except TypeError: #Type Errors may happen, but that doesn't matter as they are displayed in the gui
                 pass
             except Exception:
                 log.exception('Failed to evaluate variable block {0}'.format(variable_block.name), exc_info=True)
@@ -329,7 +330,7 @@ class FlowGraph(Element):
         connection = self.parent_platform.Connection(
             parent=self, source=porta, sink=portb)
         self.connections.add(connection)
-            
+
         return connection
 
     def disconnect(self, *ports):
@@ -423,7 +424,7 @@ class FlowGraph(Element):
 
             block.import_data(**block_data)
 
-        self.rewrite() 
+        self.rewrite()
 
         # build the connections
         def verify_and_get_port(key, block, dir):
@@ -467,7 +468,7 @@ class FlowGraph(Element):
             had_connect_errors = True
 
         for block in self.blocks:
-            if block.is_dummy_block :
+            if block.is_dummy_block:
                 block.rewrite()      # Make ports visible
                 # Flowgraph errors depending on disabled blocks are not displayed
                 # in the error dialog box
